@@ -463,6 +463,7 @@ def test_preprocess_chooseOne(args, img_id):
 
     im_dir = im_folder + '//' + im_name
     noise_im = tiff.imread(im_dir)
+    img_mean = noise_im.mean()
     # print('noise_im max -----> ',noise_im.max())
     # print('noise_im min -----> ',noise_im.min())
     if noise_im.shape[0] > args.test_datasize:
@@ -470,7 +471,11 @@ def test_preprocess_chooseOne(args, img_id):
     if args.print_img_name:
        print('Testing image name -----> ', im_name)
        print('Noise images shape -----> ', noise_im.shape)
-    noise_im = noise_im.astype(np.float32) / args.scale_factor
+    # Minus mean before training
+    noise_im = noise_im.astype(np.float32)/args.scale_factor
+    noise_im = noise_im-img_mean
+    # No preprocessing
+    # noise_im = noise_im.astype(np.float32) / args.scale_factor
     # noise_im = (noise_im-noise_im.min()).astype(np.float32)/args.scale_factor
 
     whole_x = noise_im.shape[2]
@@ -569,4 +574,4 @@ def test_preprocess_chooseOne(args, img_id):
                 # print(' single_coordinate -----> ',single_coordinate)
                 coordinate_list[patch_name] = single_coordinate
 
-    return name_list, noise_im, coordinate_list, im_name
+    return name_list, noise_im, coordinate_list, im_name, img_mean
