@@ -357,7 +357,7 @@ class training_class():
         """
         # Crop test file into 3D patches for inference
         self.print_img_name = True
-        name_list, noise_img, coordinate_list, test_im_name = test_preprocess_chooseOne(self, img_id=0)
+        name_list, noise_img, coordinate_list, test_im_name, img_mean = test_preprocess_chooseOne(self, img_id=0)
         # Record the inference time
         prev_time = time.time()
         time_start = time.time()
@@ -406,6 +406,10 @@ class training_class():
                 for id in range(postprocess_turn):
                     output_patch, raw_patch, stack_start_w, stack_end_w, stack_start_h, stack_end_h, stack_start_s, stack_end_s = multibatch_test_save(
                         single_coordinate, id, output_image, raw_image)
+
+                    output_patch=output_patch+img_mean
+                    raw_patch=raw_patch+img_mean
+
                     denoise_img[stack_start_s:stack_end_s, stack_start_h:stack_end_h, stack_start_w:stack_end_w] \
                         = output_patch * (np.sum(raw_patch) / np.sum(output_patch)) ** 0.5
                     input_img[stack_start_s:stack_end_s, stack_start_h:stack_end_h, stack_start_w:stack_end_w] \
@@ -413,6 +417,10 @@ class training_class():
             else:
                 output_patch, raw_patch, stack_start_w, stack_end_w, stack_start_h, stack_end_h, stack_start_s, stack_end_s = singlebatch_test_save(
                     single_coordinate, output_image, raw_image)
+
+                output_patch=output_patch+img_mean
+                raw_patch=raw_patch+img_mean
+
                 denoise_img[stack_start_s:stack_end_s, stack_start_h:stack_end_h, stack_start_w:stack_end_w] \
                     = output_patch * (np.sum(raw_patch) / np.sum(output_patch)) ** 0.5
                 input_img[stack_start_s:stack_end_s, stack_start_h:stack_end_h, stack_start_w:stack_end_w] \
